
Resources:

*   Understand how `@/exe/dev_shell.bash` enables command completion.

*   Also, learn about `~/.inputrc` config - see docstring `CompType.py`.

*   Readline `~/.inputrc` config docs:
    https://www.gnu.org/software/bash/manual/html_node/Readline-Init-File-Syntax.html

*   Official Bash docs:
    *   https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion.html
    *   https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion-Builtins.html
    *   https://www.gnu.org/software/bash/manual/html_node/A-Programmable-Completion-Example.html

*   Related Bash env vars, for example, starting with "COMP_":
    *   https://www.gnu.org/software/bash/manual/html_node/Bash-Variables.html
